
# Type: homologous to


holds between two biological entities that have common evolutionary origin

URI: [biolink:homologous_to](https://w3id.org/biolink/vocab/homologous_to)


## Domain and Range

[NamedThing](NamedThing.md) ->  <sub>0..*</sub> [NamedThing](NamedThing.md)

## Parents

 *  is_a: [related to](related_to.md)

## Children

 *  [orthologous to](orthologous_to.md)
 *  [paralogous to](paralogous_to.md)
 *  [xenologous to](xenologous_to.md)

## Used by

 * [NamedThing](NamedThing.md)

## Other properties

|  |  |  |
| --- | --- | --- |
| **Aliases:** | | in homology relationship with |
| **Mappings:** | | RO:HOM0000001 |
|  | | SIO:010302 |
| **Comments:** | | typically used to describe homology relationships between genes or gene products |
| **In Subsets:** | | translator_minimal |

